[Python-checkins] bpo-35224: Bump the pyc magic number by 1 instead of by 10 in last modification (GH-14320)

Pablo Galindo webhook-mailer at python.org
Sun Jun 23 12:00:12 EDT 2019


https://github.com/python/cpython/commit/b3ca7972c8d8c6479b6542ce28e0f7a6ebd5b8fe
commit: b3ca7972c8d8c6479b6542ce28e0f7a6ebd5b8fe
branch: master
author: Pablo Galindo <Pablogsal at gmail.com>
committer: GitHub <noreply at github.com>
date: 2019-06-23T17:00:08+01:00
summary:

bpo-35224: Bump the pyc magic number by 1 instead of by 10 in last modification (GH-14320)

files:
M Lib/importlib/_bootstrap_external.py
M Python/importlib_external.h

diff --git a/Python/importlib_external.h b/Python/importlib_external.h
index 01a3c8b1e343..33b2ca6820f1 100644
--- a/Python/importlib_external.h
+++ b/Python/importlib_external.h
@@ -278,7 +278,7 @@ const unsigned char _Py_M__importlib_bootstrap_external[] = {
     95,97,116,111,109,105,99,120,0,0,0,115,30,0,0,0,
     0,5,16,1,6,1,16,0,6,255,4,2,2,3,14,1,
     20,1,16,1,14,1,2,1,14,1,14,1,6,1,114,69,
-    0,0,0,105,92,13,0,0,114,28,0,0,0,114,16,0,
+    0,0,0,105,83,13,0,0,114,28,0,0,0,114,16,0,
     0,0,115,2,0,0,0,13,10,90,11,95,95,112,121,99,
     97,99,104,101,95,95,122,4,111,112,116,45,122,3,46,112,
     121,122,4,46,112,121,99,78,41,1,218,12,111,112,116,105,



More information about the Python-checkins mailing list
diff --git a/Lib/importlib/_bootstrap_external.py b/Lib/importlib/_bootstrap_external.py
index 40e239dbf6c3..64185771abc8 100644
--- a/Lib/importlib/_bootstrap_external.py
+++ b/Lib/importlib/_bootstrap_external.py
@@ -266,7 +266,7 @@ def _write_atomic(path, data, mode=0o666):
 #     Python 3.8a1  3400 (move frame block handling to compiler #17611)
 #     Python 3.8a1  3401 (add END_ASYNC_FOR #33041)
 #     Python 3.8a1  3410 (PEP570 Python Positional-Only Parameters #36540)
 #     Python 3.8b2  3420 (Reverse evaluation order of key: value in dict
 #                         comprehensions #35224)
 #
 # MAGIC must change whenever the bytecode emitted by the compiler may no
@@ -276,7 +276,7 @@ def _write_atomic(path, data, mode=0o666):
 # Whenever MAGIC_NUMBER is changed, the ranges in the magic_values array
 # in PC/launcher.c must also be updated.
 
-MAGIC_NUMBER = (3420).to_bytes(2, 'little') + b'\r\n'
+MAGIC_NUMBER = (3411).to_bytes(2, 'little') + b'\r\n'
 _RAW_MAGIC_NUMBER = int.from_bytes(MAGIC_NUMBER, 'little')  # For import.c
 
 _PYCACHE = '__pycache__'
@@ -266,7 +266,7 @@ def _write_atomic(path, data, mode=0o666):
 #     Python 3.8a1  3401 (add END_ASYNC_FOR #33041)
 #     Python 3.8a1  3410 (PEP570 Python Positional-Only Parameters #36540)
-#     Python 3.8b2  3420 (Reverse evaluation order of key: value in dict
+#     Python 3.8b2  3411 (Reverse evaluation order of key: value in dict
 #                         comprehensions #35224)
 #